@@ -222,7 +222,7 @@ class anim_text:
         self.name = name
 
         all_frames = np.arange(1, anim.frames[-1])
-        frame_interper = interp1d(anim.frames, data, fill_values = 'extrapolate')
+        frame_interper = interp1d(anim.frames, data, fill_value = 'extrapolate')
 
         fixed_data = frame_interper(all_frames)
 
